@@ -58,7 +58,7 @@ LOOKUP_TIMEOUT = 40
 
 class Device():
 
-    def read_inquiry_mode(sock):
+    def read_inquiry_mode(self, sock):
         """returns the current mode, or -1 on failure"""
         # save current filter
         old_filter = sock.getsockopt(bluez.SOL_HCI, bluez.HCI_FILTER, 14)
